Package {rjd3jars}


Title: External jars for 'rjdverse' R Packages
Version: 0.0.5
Description: It provides external jars required for the 'rjdverse' (as 'rjd3toolkit', 'rjd3x13' and 'rjd3tramoseats').
Depends: R (≥ 4.1)
Imports: rJava (≥ 1.0-6)
License: EUPL version 1.1 | EUPL version 1.2 [expanded from: EUPL]
Encoding: UTF-8
Collate: 'rjd3jars-package.R' 'utils.R' 'zzz.R'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-07 09:43:50 UTC; onyxia
Author: Tanguy Barthelemy [aut, cre]
Maintainer: Tanguy Barthelemy <timeserieswithjdemetraandr@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-07 12:10:02 UTC

rjd3jars: External jars for 'rjdverse' R Packages

Description

It provides external jars required for the 'rjdverse' (as 'rjd3toolkit', 'rjd3x13' and 'rjd3tramoseats').

Author(s)

Maintainer: Tanguy Barthelemy timeserieswithjdemetraandr@gmail.com

Authors:


Extract the Java installed version

Description

Extract the Java installed version

Usage

get_java_version()

minimal_java_version

check_java_version(silent = TRUE, startup = TRUE)

Arguments

silent

Boolean to indicate if a message should be displayed.

startup

Boolean to indicate if the function is launch at the startup of the package.

Value

get_java_version() returns the current java installed and usable version. It's an integer. minimal_java_version is the minimal java version accepted currently by JDemetra+. check_java_version() returns TRUE or FALSE if the current version of Java is greater than or equal to the minimum required version.

Examples

print(minimal_java_version)
print(get_java_version())
check_java_version()


Reload dictionaries

Description

Reload dictionaries

Usage

reload_dictionaries()

Value

invisibly NULL

Examples


reload_dictionaries()


Reload all seasonal adjustment factories

Description

Reload all seasonal adjustment factories

Usage

reload_safactories()

Examples


reload_safactories()


Reload all the time series providers

Description

Reload all the time series providers

Usage

reload_tsproviders()

Value

invisibly NULL

Examples


reload_tsproviders()