| Type: | Package |
| Title: | External jars for 'rjdverse' R Packages |
| Version: | 0.0.6 |
| Description: | It provides external jars required for the 'rjdverse' (as 'rjd3toolkit', 'rjd3x13' and 'rjd3tramoseats'). |
| URL: | https://github.com/rjdverse/rjd3jars, https://rjdverse.github.io/rjd3jars/ |
| BugReports: | https://github.com/rjdverse/rjd3jars/issues |
| Depends: | R (≥ 4.1) |
| Imports: | rJava (≥ 1.0-6) |
| License: | EUPL version 1.1 | EUPL version 1.2 [expanded from: EUPL] |
| Encoding: | UTF-8 |
| Collate: | 'rjd3jars-package.R' 'java.R' 'utils.R' 'zzz.R' |
| SystemRequirements: | Java (>= 21) |
| Config/roxygen2/version: | 8.1.0 |
| Suggests: | spelling |
| Language: | en-GB |
| NeedsCompilation: | no |
| Packaged: | 2026-09-18 08:37:44 UTC; SHT3RT |
| Author: | Tanguy Barthelemy [aut, cre, cph] |
| Maintainer: | Tanguy Barthelemy <timeserieswithjdemetraandr@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-18 09:20:38 UTC |
rjd3jars: External jars for 'rjdverse' R Packages
Description
It provides external jars required for the 'rjdverse' (as 'rjd3toolkit', 'rjd3x13' and 'rjd3tramoseats').
Author(s)
Maintainer: Tanguy Barthelemy timeserieswithjdemetraandr@gmail.com [copyright holder]
Authors:
Tanguy Barthelemy timeserieswithjdemetraandr@gmail.com [copyright holder]
See Also
Useful links:
Report bugs at https://github.com/rjdverse/rjd3jars/issues
Extract the Java installed version
Description
Extract the Java installed version
Usage
get_java_version()
minimal_java_version
check_java_version(silent = TRUE, startup = TRUE)
Arguments
silent |
Boolean to indicate if a message should be displayed. |
startup |
Boolean to indicate if the function is launch at the startup of the package. |
Value
get_java_version() returns the current Java installed and usable
version. It's an integer.
minimal_java_version is the minimal Java version accepted currently by
JDemetra+.
check_java_version() returns TRUE or FALSE if the current version of
Java is greater than or equal to the minimum required version.
Examples
print(minimal_java_version)
print(get_java_version())
check_java_version()
Reload dictionaries
Description
Reload dictionaries
Usage
reload_dictionaries()
Value
invisibly NULL
Examples
reload_dictionaries()
Reload all seasonal adjustment factories
Description
Reload all seasonal adjustment factories
Usage
reload_safactories()
Value
invisibly NULL
Examples
reload_safactories()
Reload all the time series providers
Description
Reload all the time series providers
Usage
reload_tsproviders()
Value
invisibly NULL
Examples
reload_tsproviders()